@@ -691,7 +691,11 @@ class AquaSource(NvdSource):
         assigner = "photon"
         score = cve_data.get("cve_score")
         severity = convert_score_severity(score)
-        score, severity, vectorString, attackComplexity = get_default_cve_data(severity)
+        newscore, severity, vectorString, attackComplexity = get_default_cve_data(
+            severity
+        )
+        if not score and newscore:
+            score = newscore
         publishedDate = ""
         lastModifiedDate = ""
         version_start_including = ""
@@ -702,6 +706,10 @@ class AquaSource(NvdSource):
         fix_version_start_excluding = ""
         fix_version_end_excluding = ""
         fix_version_start_including = cve_data.get("res_ver").split(":")[-1]
+        distro_name = "*"
+        if cve_data.get("os_version"):
+            distro_name = f"""photon-{cve_data.get("os_version")}"""
+            pkg_name = f"{distro_name}/{pkg_name}"
         if pkg_name and version_end_excluding:
             tdata = config.CVE_TPL % dict(
                 cve_id=cve_id,
@@ -713,7 +721,7 @@ class AquaSource(NvdSource):
                 vendor="photon",
                 product=pkg_name,
                 version="*",
-                edition="*",
+                edition=distro_name,
                 version_start_including=version_start_including,
                 version_end_including=version_end_including,
                 version_start_excluding=version_start_excluding,
