@@ -8,9 +8,8 @@ from cvss import CVSS3
 from packageurl import PackageURL
 from semver import VersionInfo
 
-from collections import Counter
-
 from vdb.lib import CPE_FULL_REGEX, PackageIssue, Severity, VulnerabilityOccurrence
+from vdb.lib.config import placeholder_fix_version
 
 date_format_str = "%Y-%m-%dT%H:%M:%S"
 
@@ -458,6 +457,18 @@ def version_compare(
     >>> utils.version_compare("4.0.0", "2.0.0", "*")
     True
     """
+    # Handle placeholder fix version
+    if max_affected_version_excluding == placeholder_fix_version and compare_ver:
+        return True
+    # Fix min versions that are erroneously sent as *
+    if (
+        min_version
+        and min_version == "*"
+        and not min_affected_version_excluding
+        and max_affected_version_excluding
+        and "." in max_affected_version_excluding
+    ):
+        min_version = 0
     hash_mode_detected = is_hash_mode(
         compare_ver,
         min_version,
